/**********************************************************************\
**
**                         Copyright (c) 2008-2022 by
**                          HENGSTLER GmbH, Aldingen
**
**      This  software  is furnished under a license and may be used and
**      copied only in accordance with the terms  of  such  license  and
**      with the inclusion of the above copyright notice.  This software
**      or any other copies thereof may not  be  provided  or  otherwise
**      made  available  to any other person.  No title to and ownership
**      of the software is hereby transferred.
**
**      The  information  in  this software is subject to change without
**      notice and should not be construed as a commitment by Hengstler.
**
**  Module:      Xpm_Pmpt_DlgMain.h
**  Facility:    S690001 - Hengstler XPM Printer Driver for Windows XP/7/8/10 
**  Component:   XPM print monitor plugin test tool (Xpm-PrintMonPluginTest)
**  Version:     R8-V1.07-FINAL / 2022OCT18
**  Environment: Windows XP/7/8/10
**  Compiler:    Microsoft Visual Studio 2015
**  Abstract:    Header file of module Xpm_Pmpt_DlgMain.cpp
**  Note:        -
**  History:     R1-V1.00c / 2008JUL11 / HOR / 1st RELEASE - 1st BETA
**               R1-V1.00d / 2008DEC11 / HOR / 1st RELEASE - 2nd BETA
**               R1-V1.00e / 2009MAY05 / HOR / 1st RELEASE - 3rd BETA
**               R1-V1.00f / 2009JUL16 / HOR / 1st RELEASE - 4th BETA
**               R1-V1.00  / 2009AUG27 / HOR / 1st RELEASE - FINAL 
**               ------------------------------------------------------------
**               R2-V1.01a / 2010JAN26 / HOR / 2nd RELEASE - 1st BETA 
**               R2-V1.01b / 2010MAR04 / HOR / 2nd RELEASE - 2nd BETA
**               R2-V1.01c / 2011DEC19 / HOR / M-R2-012-HOR
**                  Complete driver package converted to VS2010 and adapted to Windows 7 32/64 bit
**               R2-V1.01c / 2011DEC19 / HOR / 2nd RELEASE - 3rd BETA
**               R2-V1.01d / 2012JUN27 / HOR / 2nd RELEASE - 4th BETA
**               R2-V1.01e / 2015MAY05 / HOR / 2nd RELEASE - 5th BETA
**               R2-V1.01f / 2016FEB15 / HOR / 2nd RELEASE - 6th BETA
**               R2-V1.01  / 2016AUG19 / HOR / M-R2-041-HOR
**                 Complete driver package converted to VS2015 and adapted to Windows 8/10 32/64 bit
**               R2-V1.01  / 2016AUG19 / HOR / 2nd RELEASE - FINAL
**               ------------------------------------------------------------
**               R3-V1.02  / 2016AUG24 / HOR / M-R3-001-HOR
**                 Additional driver package compilation added for usage within Windows-XP.
**               R3-V1.02  / 2016AUG24 / HOR / 3rd RELEASE - FINAL
**               ------------------------------------------------------------
**               R4-V1.03  / 2018JUL10 / HOR / 4th RELEASE - FINAL
**               ------------------------------------------------------------
**               R5-V1.04  / 2018OCT11 / HOR / 5th RELEASE - FINAL
**               ------------------------------------------------------------
**               R6-V1.05  / 2018DEC07 / HOR / 6th RELEASE - FINAL
**               ------------------------------------------------------------
**               R7-V1.06  / 2022FEB10 / HOR / 7th RELEASE - FINAL
**               ------------------------------------------------------------
**               R8-V1.07  / 2022OCT18 / HOR / 8th RELEASE - FINAL
**               ------------------------------------------------------------
**
\**********************************************************************/

#ifndef __XPMPMPT_DLGMAIN_H
#define __XPMPMPT_DLGMAIN_H

/*
** COMPILER
*/

#pragma once


/*
** INCLUDES
*/

#include "..\..\Libraries\Xpm_PrintMonPlugin.h"

/*
** COMPILER 
*/

/*
** MACROS
*/

/*
** TYPES
*/

/*
** CLASSES
*/

class CXpm_Pmpt_DlgMain : public CDialog
{
   public:

      //-- Constructor/destructor
      CXpm_Pmpt_DlgMain                                     (CWnd* pParent = NULL);
      ~CXpm_Pmpt_DlgMain                                    ();


      //-- Identifier of corresponding resource
      enum                { IDD = IDD_DLG_MAIN };

   protected:

      //-- DDX/DDV support
      virtual void        DoDataExchange                    (CDataExchange* pDX);   

      //-- Dialog icons
      HICON               m_hIconL;                         // Handle of large icon 
      HICON               m_hIconS;                         // Handle of small icon
  
      //-- Dialog overwrites
      virtual BOOL        OnInitDialog                      ();

      //-- AFX messages
      afx_msg void        OnSysCommand                      (UINT nID, LPARAM lParam);
      afx_msg void        OnPaint                           ();
      afx_msg HCURSOR     OnQueryDragIcon                   ();
      afx_msg void        OnTimer                           (UINT nIDEvent);
 
      //-- Declare message map
      DECLARE_MESSAGE_MAP()

   private:
   
      //-- Methods for reading data from registry 
      bool               ReadPrinterDataFromRegistry        (PSTR pszPrinter, PSTR pszKey, PSTR pszValue, PBYTE pubData, DWORD dwSize);

      //-- Methods for updating the dialog 
      void               UpdateDialog                       ();
      void               UpdateJobInfoInDialog              (PS_XPM_PMP_JOB_INFO psJobInfo);
      void               UpdatePrinterInfoInDialog          (PS_XPM_PMP_PRINTER_INFO psPrinterInfo);
      void               UpdatePrinterStatusInDialog        (PS_XPM_PMP_PRINTER_STATUS psPrinterStatus);
      void               UpdatePrinterPresentInDialog       (PS_XPM_PMP_PRINTER_PRESENT psPrinterPresent);
      void               UpdatePrinterFeedInDialog          (PS_XPM_PMP_PRINTER_FEED psPrinterFeed);

      //-- Member variables
      UINT_PTR           m_iTimer;                          // Timer for periodical update
      PSTR               m_pszPrinter;                      // Selected printer

public:
   afx_msg void OnCbnSelchangeComboPrinterDriver();
};

/*
** VARIABLES
*/

#endif