/**********************************************************************\
**
**                          Copyright (c) 2008-2022 by
**                          HENGSTLER GmbH, Aldingen
**
**      This  software  is furnished under a license and may be used and
**      copied only in accordance with the terms  of  such  license  and
**      with the inclusion of the above copyright notice.  This software
**      or any other copies thereof may not  be  provided  or  otherwise
**      made  available  to any other person.  No title to and ownership
**      of the software is hereby transferred.
**
**      The  information  in  this software is subject to change without
**      notice and should not be construed as a commitment by Hengstler.
**
**  Module:      Xpm_Pmp_LogMan.h
**  Facility:    S690001 - Hengstler XPM Printer Driver for Windows XP/7/8/10
**  Component:   Print monitor (Xpm-PrintMon)
**  Version:     R8-V1.07-FINAL / 2022OCT18
**  Environment: Windows XP/7/8/10
**  Compiler:    Microsoft Visual Studio 2015
**  Abstract:    Header file of module Xpm_Pmp_LogMan.cpp
**  Note:        -
**  History:     R1-V1.00c / 2008JUL11 / HOR / 1st RELEASE - 1st BETA
**               R1-V1.00d / 2008DEC11 / HOR / 1st RELEASE - 2nd BETA
**               R1-V1.00e / 2009MAY05 / HOR / 1st RELEASE - 3rd BETA
**               R1-V1.00f / 2009JUL16 / HOR / 1st RELEASE - 4th BETA
**               R1-V1.00  / 2009AUG27 / HOR / 1st RELEASE - FINAL 
**               ------------------------------------------------------------
**               R2-V1.01a / 2010JAN26 / HOR / 2nd RELEASE - 1st BETA 
**               R2-V1.01b / 2010MAR04 / HOR / 2nd RELEASE - 2nd BETA
**               R2-V1.01c / 2011DEC19 / HOR / M-R2-012-HOR
**                  Complete driver package converted to VS2010 and adapted to Windows 7 32/64 bit
**               R2-V1.01c / 2011DEC19 / HOR / 2nd RELEASE - 3rd BETA
**               R2-V1.01d / 2012JUN27 / HOR / 2nd RELEASE - 4th BETA
**               R2-V1.01e / 2015MAY05 / HOR / 2nd RELEASE - 5th BETA
**               R2-V1.01f / 2016FEB15 / HOR / 2nd RELEASE - 6th BETA
**               R2-V1.01  / 2016AUG19 / HOR / M-R2-041-HOR
**                 Complete driver package converted to VS2015 and adapted to Windows 8/10 32/64 bit
**               R2-V1.01  / 2016AUG19 / HOR / 2nd RELEASE - FINAL
**               ------------------------------------------------------------
**               R3-V1.02  / 2016AUG24 / HOR / M-R3-001-HOR
**                 Additional driver package compilation added for usage within Windows-XP.
**               R3-V1.02  / 2016AUG24 / HOR / 3rd RELEASE - FINAL
**               ------------------------------------------------------------
**               R4-V1.03  / 2018JUL10 / HOR / 4th RELEASE - FINAL
**               ------------------------------------------------------------
**               R5-V1.04  / 2018OCT11 / HOR / 5th RELEASE - FINAL
**               ------------------------------------------------------------
**               R6-V1.05  / 2018DEC07 / HOR / 6th RELEASE - FINAL
**               ------------------------------------------------------------
**               R7-V1.06  / 2022FEB10 / HOR / 7th RELEASE - FINAL
**               ------------------------------------------------------------
**               R8-V1.07  / 2022OCT18 / HOR / 8th RELEASE - FINAL
**               ------------------------------------------------------------
**
\**********************************************************************/

#ifndef __XPM_PMPLOGMAN_H
#define __XPM_PMPLOGMAN_H

/*
** INCLUDES
*/
#include <stdio.h>
/*
** COMPILER 
*/

/*
** MACROS
*/

/*
** TYPES
*/

/*
** FUNCTIONS
*/

/*
** CLASS     CXpm_Pmp_LogMan
** ABSTRACT  Manager for port I/O
*/
class CXpm_Pmp_LogMan {

   public:

      //-- Constructor/destructor
      CXpm_Pmp_LogMan                                    ();
      ~CXpm_Pmp_LogMan                                   ();

      //-- Methods for "logging" to file
      void   LogPrint                                    (PSTR pszInfo, PSTR pszFormat, ...);
      void   LogData                                     (PBYTE pubData, INT nData, char cFlag);

   private:

      //-- Methods for "logging" to file
      void   OpenLogFile                                 (void);
      void   CloseLogFile                                (void);
      void   ManageLogFile                               (void);

      //-- Methods for print monitor info structure 
      VOID   InitPmInfoStructure                         (VOID);
      BOOL   WritePmInfoToRegistry                       (VOID);

       //-- Methods for print monitor settings structure 
      BOOL   ReadPmSettingsFromRegistry                  (VOID);

   private:

      //-- Member variables
      CRITICAL_SECTION                                   m_csAccess;            // Mutex for exclusive accessing print monitor 
      char                                               m_szLogFile[MAX_PATH]; // Path to log file
      FILE                                             * m_pfLogFile;           // Pointer to log file
      SYSTEMTIME                                         m_sLogFileSysTime;     // Time stamp of log file open
      bool                                               m_fLogIoOnly;          // Flag indicating log data only
};


/*
** VARIABLES
*/

#endif